@@ -10,7 +10,6 @@
 import sys
 import traceback
 
-import rtmidi
 import gc
 
 from ..model.clip import Clip
@@ -25,6 +24,7 @@ from ..model.track import Track
 from ..model.transform import Transform
 from ..playback.realtime_engine import RealtimeEngine
 from ..playback.multi_player import MultiPlayer
+from ..playback.midi import get_devices
 from .callbacks import Callbacks, DefaultCallback
 from .exceptions import *
 from .support import BaseApi
@@ -34,8 +34,7 @@ gc.disable()
 
 # =====================================================================================================================
 
-midi_out = rtmidi.MidiOut()
-MIDI_PORTS = midi_out.get_ports()
+MIDI_PORTS = get_devices()
 
 # =====================================================================================================================
 
